==> 0.1.4.tar.gz: ios/Classes/MolliePlugin.m <==
#import "MolliePlugin.h"

@interface MolliePlugin ()
@property (nonatomic, strong) UIViewController *viewController;
@end

@implementation MolliePlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {

  FlutterMethodChannel* channel = [FlutterMethodChannel
                                       methodChannelWithName:@"mollie"
                                       binaryMessenger:[registrar messenger]];

  UIViewController *viewController = [UIApplication sharedApplication].delegate.window.rootViewController;
  MolliePlugin *instance = [[MolliePlugin alloc] initWithViewController:viewController];
  [registrar addMethodCallDelegate:instance channel:channel];

}

- (instancetype)initWithViewController:(UIViewController *)viewController {
    self = [super init];

    if (self) {
        _viewController = viewController;
    }

    return self;
}



- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {

    if ([@"startPayment" isEqualToString:call.method]) {

        NSString *checkoutUrl = call.arguments[@"checkoutUrl"];
        [[UIApplication sharedApplication] openURL:[NSURL URLWithString: checkoutUrl]];

//        if (@available(iOS 11, *)) {
//            [[UIApplication sharedApplication] open:[checkoutUrl, completionHandler: nil]];
////            UIApplication.shared.open(checkoutUrl, options: [:], completionHandler: nil)
//        } else {
////            UIApplication.shared.openURL(checkoutUrl)
//        }
        
    }
    else
    {
        result(FlutterMethodNotImplemented);
    }
}

@end

==> 0.1.5.tar.gz: ios/Classes/MolliePlugin.m <==
#import "MolliePlugin.h"

@interface MolliePlugin ()
@property (nonatomic, strong) UIViewController *viewController;
@end

@implementation MolliePlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {

  FlutterMethodChannel* channel = [FlutterMethodChannel
                                       methodChannelWithName:@"fluttermollie"
                                       binaryMessenger:[registrar messenger]];

  UIViewController *viewController = [UIApplication sharedApplication].delegate.window.rootViewController;
  MolliePlugin *instance = [[MolliePlugin alloc] initWithViewController:viewController];
  [registrar addMethodCallDelegate:instance channel:channel];

}

- (instancetype)initWithViewController:(UIViewController *)viewController {
    self = [super init];

    if (self) {
        _viewController = viewController;
    }

    return self;
}



- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {

    if ([@"startPayment" isEqualToString:call.method]) {

        NSString *checkoutUrl = call.arguments[@"checkoutUrl"];
        [[UIApplication sharedApplication] openURL:[NSURL URLWithString: checkoutUrl]];

//        if (@available(iOS 11, *)) {
//            [[UIApplication sharedApplication] open:[checkoutUrl, completionHandler: nil]];
////            UIApplication.shared.open(checkoutUrl, options: [:], completionHandler: nil)
//        } else {
////            UIApplication.shared.openURL(checkoutUrl)
//        }
        
    }
    else
    {
        result(FlutterMethodNotImplemented);
    }
}

@end
